"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var util_1 = tslib_1.__importDefault(require("util"));
var fs_1 = require("fs");
var mkdirp_1 = tslib_1.__importDefault(require("mkdirp"));
var execa_1 = tslib_1.__importDefault(require("execa"));
var path_1 = require("path");
var lodash_1 = require("lodash");
var rollup_1 = require("rollup");
var ts_lib_scripts_utils_1 = require("ts-lib-scripts-utils");
var create_rollup_options_1 = require("./config/create-rollup-options");
var logError_1 = tslib_1.__importDefault(require("./logError"));
var paths_1 = require("./config/paths");
// eslint-disable-next-line @typescript-eslint/no-var-requires
var createLogger = require('progress-estimator');
var logger = createLogger({
    storagePath: path_1.resolve(__dirname, '.progress-estimator'),
});
/**
 * 创建index.js文件
 *
 * @param {string} outDir 输出目录
 *
 * @export
 */
function createCjsIndexFile(outDir) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var content;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, util_1.default.promisify(fs_1.readFile)(path_1.resolve(__dirname, '../assets/index.js.tpl'), 'utf-8')];
                case 1:
                    content = _a.sent();
                    return [4 /*yield*/, util_1.default.promisify(mkdirp_1.default)(outDir)];
                case 2:
                    _a.sent();
                    return [4 /*yield*/, util_1.default.promisify(fs_1.writeFile)(path_1.resolve(outDir, 'index.js'), content.replace(/\{packageName\}/g, ts_lib_scripts_utils_1.safePackageName(paths_1.getAppPackageInfo().name)))];
                case 3:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    });
}
exports.createCjsIndexFile = createCjsIndexFile;
/**
 * 生成.d.ts文件
 *
 * @export
 */
function createTsDeclarationFiles(buildOptions) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, execa_1.default('yarn', [
                        'tsc',
                        '-d',
                        '--emitDeclarationOnly',
                        '--skipLibCheck',
                        '--declarationDir',
                        buildOptions.outDir,
                    ].filter(Boolean), {
                        cwd: paths_1.rootPath,
                    })];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    });
}
exports.createTsDeclarationFiles = createTsDeclarationFiles;
/**
 * 运行编译命令
 *
 * @export
 * @param {BuildOptions} buildOptions 构建命令参数
 */
function runBuild(buildOptions) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var formats, envs, buildPromise, error_1;
        var _this = this;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    formats = buildOptions.format;
                    envs = ['production', 'development'];
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 5, , 6]);
                    return [4 /*yield*/, logger(createTsDeclarationFiles(buildOptions), '使用tsc生成.d.ts文件')];
                case 2:
                    _a.sent();
                    return [4 /*yield*/, logger(createCjsIndexFile(buildOptions.outDir), '生成dist/index.js文件(cjs入口文件)')];
                case 3:
                    _a.sent();
                    buildPromise = Promise.all(lodash_1.flatMap(formats, function (formatMode) {
                        return envs.map(function (env) { return create_rollup_options_1.createRollupOptions(formatMode, env, buildOptions); });
                    }).map(function (_a) {
                        var inputOptions = _a[0], outputOptions = _a[1];
                        return tslib_1.__awaiter(_this, void 0, void 0, function () {
                            var bundle;
                            return tslib_1.__generator(this, function (_b) {
                                switch (_b.label) {
                                    case 0: return [4 /*yield*/, rollup_1.rollup(inputOptions)];
                                    case 1:
                                        bundle = _b.sent();
                                        return [4 /*yield*/, bundle.write(outputOptions)];
                                    case 2:
                                        _b.sent();
                                        return [2 /*return*/];
                                }
                            });
                        });
                    }));
                    return [4 /*yield*/, logger(buildPromise, '使用rollup编译js文件')];
                case 4:
                    _a.sent();
                    return [3 /*break*/, 6];
                case 5:
                    error_1 = _a.sent();
                    logError_1.default(error_1);
                    return [3 /*break*/, 6];
                case 6: return [2 /*return*/];
            }
        });
    });
}
exports.runBuild = runBuild;
//# sourceMappingURL=build.js.map