"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/* eslint-disable no-console */
var chalk_1 = tslib_1.__importDefault(require("chalk"));
var path_1 = require("path");
var paths_1 = require("./paths");
/* eslint-disable import/prefer-default-export */
/**
 * 创建Jest配置
 */
function createJestConfig() {
    var jestConfig = {
        transform: {
            '^.+\\.(js|jsx|ts|tsx)$': path_1.resolve(__dirname, './jest/babelTransform.js'),
            '^.+\\.css$': path_1.resolve(__dirname, './jest/cssTransform.js'),
            '^(?!.*\\.(js|jsx|ts|tsx|css|json)$)': path_1.resolve(__dirname, './jest/fileTransform.js'),
        },
        transformIgnorePatterns: [
            '[/\\\\]node_modules[/\\\\].+\\.(js|jsx|ts|tsx)$',
            '^.+\\.module\\.(css|sass|scss)$',
        ],
        collectCoverageFrom: ['src/**/*.{ts,tsx}', '!src/**/*.d.ts'],
        watchPathIgnorePatterns: ['<rootDir>/node_modules/'],
        testRegex: '.*\\.(spec|test)\\.tsx?$',
        watchPlugins: [
            'jest-watch-typeahead/filename',
            'jest-watch-typeahead/testname',
        ],
        moduleNameMapper: {
            '^react-native$': 'react-native-web',
            '^.+\\.module\\.(css|sass|scss)$': 'identity-obj-proxy',
        },
    };
    var overrides = Object.assign({}, paths_1.getAppPackageInfo().jest);
    var supportedKeys = [
        'collectCoverageFrom',
        'coverageReporters',
        'coverageThreshold',
        'extraGlobals',
        'globalSetup',
        'globalTeardown',
        'moduleNameMapper',
        'resetMocks',
        'resetModules',
        'snapshotSerializers',
        'transform',
        'transformIgnorePatterns',
        'watchPathIgnorePatterns',
        'testRegex',
    ];
    if (overrides) {
        supportedKeys.forEach(function (key) {
            if (overrides[key] !== undefined || overrides[key] !== null) {
                if (Array.isArray(jestConfig[key]) ||
                    typeof jestConfig[key] !== 'object') {
                    // for arrays or primitive types, directly override the config key
                    jestConfig[key] = overrides[key];
                }
                else {
                    // for object types, extend gracefully
                    jestConfig[key] = Object.assign({}, jestConfig[key], overrides[key]);
                }
                delete overrides[key];
            }
        });
        var unsupportedKeys = Object.keys(overrides);
        if (unsupportedKeys.length) {
            var isOverridingSetupFile = unsupportedKeys.indexOf('setupFilesAfterEnv') > -1;
            if (isOverridingSetupFile) {
                console.error(chalk_1.default.red("\u5728package.json\u4E2D\u53D1\u73B0\u4E86" + chalk_1.default.bold('setupFilesAfterEnv') + "\u3002\n\n" +
                    ("\u8BF7\u5C06\u5B83\u5220\u9664\u6389, \u5E76\u5C06\u4F60\u7684\u521D\u59CB\u5316\u4EE3\u7801\u653E\u5728 " + chalk_1.default.bold('src/setupTests.js') + "\u3002\n\u8FD9\u4E2A\u6587\u4EF6\u4F1A\u81EA\u52A8\u52A0\u8F7D\u3002\n")));
            }
            else {
                console.error(chalk_1.default.red("" + '\nts-lib-scripts只支持以下Jest扩展配置:\n\n' + supportedKeys
                    .map(function (_) { return chalk_1.default.bold("  \u2022 " + _); })
                    .join('\n') + "\u3002\n\n" +
                    ("\u4EE5\u4E0B\u5728package.json\u7684jest\u914D\u7F6E\u4E0D\u88ABts-lib-scripts\u652F\u6301\uFF1A\n\n" + unsupportedKeys
                        .map(function (_) { return chalk_1.default.bold("  \u2022 " + _); })
                        .join('\n'))));
            }
            process.exit(1);
        }
    }
    return jestConfig;
}
exports.createJestConfig = createJestConfig;
//# sourceMappingURL=create-jest-config.js.map