import { InputOptions, OutputOptions } from 'rollup';
/**
 * 创建rollup输入配置选项
 *
 * @export
 * @param {('es' | 'cjs' | 'umd')} format 打包后js文件的格式
 * @param {('development' | 'production')} env 打包后js文件的运行环境
 * @param {BuildOptions} input 打包配置项
 * @returns
 */
export declare function createRollupInputOptions(format: 'es' | 'cjs' | 'umd', env: 'development' | 'production', input: BuildOptions, watchMode: boolean): InputOptions;
/**
 * 创建rollup输出配置选项
 *
 * @export
 * @param {('es' | 'cjs' | 'umd')} format 打包后js文件的格式
 * @param {('development' | 'production')} env 打包后js文件的运行环境
 *
 * @returns
 */
export declare function createRollupOutputOptions(format: 'es' | 'cjs' | 'umd', env: 'development' | 'production', input: BuildOptions): OutputOptions;
/**
 * 创建rollup配置项
 *
 * @export
 * @param {('es' | 'cjs' | 'umd')} format 格式化
 * @param {('development' | 'production')} env 运行环境
 * @param {BuildOptions} input 打包配置项
 * @returns {[InputOptions, OutputOptions]} 返回rollup输入和输出配置项数组，第一项为输入配置，第二项为输出配置。
 */
export declare function createRollupOptions(format: 'es' | 'cjs' | 'umd', env: 'development' | 'production', input: BuildOptions, watchMode?: boolean): [InputOptions, OutputOptions];
