"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var rollup_plugin_node_resolve_1 = tslib_1.__importDefault(require("rollup-plugin-node-resolve"));
var rollup_plugin_commonjs_1 = tslib_1.__importDefault(require("rollup-plugin-commonjs"));
var rollup_plugin_json_1 = tslib_1.__importDefault(require("rollup-plugin-json"));
var rollup_plugin_replace_1 = tslib_1.__importDefault(require("rollup-plugin-replace"));
var rollup_plugin_sourcemaps_1 = tslib_1.__importDefault(require("rollup-plugin-sourcemaps"));
var rollup_plugin_terser_1 = require("rollup-plugin-terser");
var rollup_plugin_babel_1 = tslib_1.__importDefault(require("rollup-plugin-babel"));
var rollup_plugin_typescript2_1 = tslib_1.__importDefault(require("rollup-plugin-typescript2"));
var utils_1 = require("../utils");
var create_babel_config_1 = require("./create-babel-config");
var constants_1 = require("./constants");
var paths_1 = require("./paths");
/**
 * 创建rollup输入配置选项
 *
 * @export
 * @param {('es' | 'cjs' | 'umd')} format 打包后js文件的格式
 * @param {('development' | 'production')} env 打包后js文件的运行环境
 * @param {BuildOptions} input 打包配置项
 * @returns
 */
function createRollupInputOptions(format, env, input, watchMode) {
    var inputOptions = {
        external: utils_1.external,
        input: input.entry,
        treeshake: {
            propertyReadSideEffects: false,
        },
        plugins: [
            rollup_plugin_node_resolve_1.default({
                mainFields: input.target === 'web' ? constants_1.MAIN_FIELDS_FOR_WEB : constants_1.MAIN_FIELDS_FOR_NODE,
                extensions: constants_1.moduleFileExtensions,
            }),
            format === 'umd' &&
                rollup_plugin_commonjs_1.default({
                    include: /\/node_modules\//,
                }),
            rollup_plugin_json_1.default(),
            watchMode &&
                rollup_plugin_typescript2_1.default({
                    typescript: require('typescript'),
                    cacheRoot: "./.cache/.rts2_cache_" + format,
                    tsconfigDefaults: {
                        compilerOptions: {
                            sourceMap: true,
                            declaration: true,
                            jsx: 'react',
                        },
                    },
                    tsconfigOverride: {
                        compilerOptions: {
                            target: 'esnext',
                        },
                    },
                }),
            rollup_plugin_babel_1.default(tslib_1.__assign({ babelrc: false, runtimeHelpers: format !== 'umd', exclude: ['**/node_modules/**'], extensions: constants_1.moduleFileExtensions }, create_babel_config_1.createBabelConfig(format, env))),
            rollup_plugin_replace_1.default({
                'process.env.NODE_ENV': JSON.stringify(env),
            }),
            rollup_plugin_sourcemaps_1.default(),
            env === 'production' &&
                rollup_plugin_terser_1.terser({
                    sourcemap: true,
                    output: { comments: false },
                    compress: {
                        keep_infinity: true,
                        pure_getters: true,
                        collapse_vars: false,
                    },
                    ecma: 5,
                    toplevel: true,
                    warnings: true,
                }),
        ].filter(Boolean),
    };
    return inputOptions;
}
exports.createRollupInputOptions = createRollupInputOptions;
/**
 * 创建rollup输出配置选项
 *
 * @export
 * @param {('es' | 'cjs' | 'umd')} format 打包后js文件的格式
 * @param {('development' | 'production')} env 打包后js文件的运行环境
 *
 * @returns
 */
function createRollupOutputOptions(format, env, input) {
    var outputOptions = {
        file: utils_1.getOutputFilePath(input.outDir, format, env),
        name: input.name,
        sourcemap: true,
        globals: paths_1.globals,
        format: format,
        freeze: false,
        esModule: format === 'es',
        exports: 'named',
    };
    return outputOptions;
}
exports.createRollupOutputOptions = createRollupOutputOptions;
/**
 * 创建rollup配置项
 *
 * @export
 * @param {('es' | 'cjs' | 'umd')} format 格式化
 * @param {('development' | 'production')} env 运行环境
 * @param {BuildOptions} input 打包配置项
 * @returns {[InputOptions, OutputOptions]} 返回rollup输入和输出配置项数组，第一项为输入配置，第二项为输出配置。
 */
function createRollupOptions(format, env, input, watchMode) {
    if (watchMode === void 0) { watchMode = false; }
    return [
        createRollupInputOptions(format, env, input, watchMode),
        createRollupOutputOptions(format, env, input),
    ];
}
exports.createRollupOptions = createRollupOptions;
//# sourceMappingURL=create-rollup-options.js.map