"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var fs_extra_1 = require("fs-extra");
var path_1 = require("path");
var constants_1 = require("./constants");
/**
 * 项目根目录
 */
exports.rootPath = fs_extra_1.realpathSync(process.cwd());
/**
 * 将相对于项目根目录的路径解析为绝对路径
 *
 * @param relativePath 相对路径
 */
exports.resolveRoot = function (relativePath) {
    return path_1.resolve(exports.rootPath, relativePath);
};
/**
 * 命令行工具的配置
 */
exports.cliPackageInfo = fs_extra_1.readJsonSync(path_1.resolve(__dirname, '../../package.json'));
/**
 * 获取项目配置
 */
function getAppPackageInfo() {
    return fs_extra_1.readJsonSync(exports.resolveRoot('package.json'));
}
exports.getAppPackageInfo = getAppPackageInfo;
/**
 * 项目版本号
 */
exports.getAppVersion = function () {
    return getAppPackageInfo().version;
};
/**
 * 解析模块的真实文件路径
 *
 * @param resolveFn 相对路径解析函数
 * @param filePath 模块相对路径
 */
exports.resolveModule = function (resolveFn, filePath) {
    var extension = constants_1.moduleFileExtensions.find(function (_) {
        return fs_extra_1.existsSync(resolveFn(filePath + "." + _));
    });
    if (extension) {
        return resolveFn(filePath + "." + extension);
    }
    return resolveFn(filePath + ".ts");
};
/**
 * 源码根路径
 */
exports.src = exports.resolveRoot(exports.rootPath);
/**
 * 入口文件路径
 */
exports.entry = exports.resolveModule(exports.resolveRoot, 'src/index');
/**
 * 测试环境初始化文件路径
 */
exports.testsSetup = exports.resolveModule(exports.resolveRoot, 'src/setupTests');
/**
 * 模板位置
 */
exports.TEMPLATE_PATH = path_1.resolve(__dirname, '../../template');
/**
 * 库对应的全局名称
 */
exports.globals = function () {
    return tslib_1.__assign({ react: 'React', 'react-native': 'ReactNative' }, getAppPackageInfo().globals);
};
//# sourceMappingURL=paths.js.map