"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/* eslint-disable import/prefer-default-export */
/* eslint-disable no-console */
var chalk_1 = tslib_1.__importDefault(require("chalk"));
var ora_1 = tslib_1.__importDefault(require("ora"));
var validatePackageName_1 = require("./validatePackageName");
var getOptions_1 = require("./getOptions");
var genProject_1 = require("./genProject");
var getInstallCmd_1 = tslib_1.__importDefault(require("./getInstallCmd"));
var messages_1 = require("./messages");
var constants_1 = require("./constants");
var paths_1 = require("../config/paths");
var logError_1 = tslib_1.__importDefault(require("../logError"));
var initGitRepository_1 = tslib_1.__importDefault(require("./initGitRepository"));
var getInstallDepsCmd_1 = tslib_1.__importDefault(require("./getInstallDepsCmd"));
var execa = require("execa");
/**
 * 创建项目
 *
 * @param projectName 项目名称
 * @param program 命令行对象
 */
function create(projectName, program) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var packageName, options, spinner, error_1, error_2;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    packageName = (program.packageName || projectName);
                    if (!validatePackageName_1.validatePackageName(packageName)) {
                        process.exit(1);
                    }
                    return [4 /*yield*/, getOptions_1.getOptions(projectName, packageName, program)];
                case 1:
                    options = _a.sent();
                    spinner = ora_1.default().start();
                    spinner.start('正在生成项目...');
                    _a.label = 2;
                case 2:
                    _a.trys.push([2, 4, , 5]);
                    return [4 /*yield*/, genProject_1.genProject(options)];
                case 3:
                    _a.sent();
                    spinner.succeed("\u5DF2\u751F\u6210\u9879\u76EE " + chalk_1.default.green(packageName));
                    return [3 /*break*/, 5];
                case 4:
                    error_1 = _a.sent();
                    spinner.fail('生成项目失败');
                    logError_1.default(error_1);
                    process.exit(1);
                    return [3 /*break*/, 5];
                case 5:
                    spinner.start(messages_1.dependenciesMessage(constants_1.dependencies, constants_1.devDependencies));
                    _a.label = 6;
                case 6:
                    _a.trys.push([6, 9, , 10]);
                    return [4 /*yield*/, execa(getInstallDepsCmd_1.default(constants_1.dependencies), {
                            cwd: paths_1.resolveRoot(projectName),
                        })];
                case 7:
                    _a.sent();
                    return [4 /*yield*/, execa(getInstallDepsCmd_1.default(constants_1.devDependencies, true), {
                            cwd: paths_1.resolveRoot(projectName),
                        })];
                case 8:
                    _a.sent();
                    spinner.succeed('安装依赖包');
                    messages_1.successMessage(getInstallCmd_1.default(), projectName);
                    return [3 /*break*/, 10];
                case 9:
                    error_2 = _a.sent();
                    spinner.fail("\u5B89\u88C5\u4F9D\u8D56\u5931\u8D25");
                    messages_1.failureMessage([
                        getInstallDepsCmd_1.default(constants_1.dependencies),
                        getInstallDepsCmd_1.default(constants_1.devDependencies, true),
                    ]);
                    process.exit(1);
                    return [3 /*break*/, 10];
                case 10:
                    spinner.start('初始化git');
                    try {
                        if (initGitRepository_1.default(paths_1.resolveRoot(options.projectName))) {
                            spinner.succeed('初始化git成功');
                        }
                        else {
                            spinner.stop();
                            console.log('提示：您没有安装git或者项目已经在git仓库中，无法为您的项目初始化git。');
                        }
                    }
                    catch (error) {
                        spinner.fail('初始化git失败');
                        logError_1.default(error);
                        process.exit(1);
                    }
                    return [2 /*return*/];
            }
        });
    });
}
exports.default = create;
//# sourceMappingURL=index.js.map