"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/* eslint-disable no-console */
var commander_1 = require("commander");
var chalk_1 = tslib_1.__importDefault(require("chalk"));
var build_1 = require("./build");
var utils_1 = require("./utils");
var getBuildOptions_1 = require("./config/getBuildOptions");
var paths_1 = require("./config/paths");
var test_1 = require("./test");
var lint_1 = require("./lint");
var format_1 = require("./format");
var watch_1 = require("./watch");
var constants_1 = require("./config/constants");
var create_1 = tslib_1.__importDefault(require("./create"));
var program = new commander_1.Command('ts-lib-scripts');
program.version(paths_1.cliPackageInfo.version);
program
    .command('create <projectName>')
    .description('创建TypeScript项目。')
    .option('--packageVersion <version>', '项目版本号', '0.1.0')
    .option('--packageName <name>', '项目名称，默认与projectName。packageName用于package.json中的name，而projectName则用于项目的根目录名称。')
    .option('--target <target>', '库构建的目标，可选项为web和node', 'web')
    .option('-i', '以交互的方式创建项目')
    .option('--packageDescription,-d <description>', '添加项目描述')
    .option('--author <author>', '指定作者')
    .action(function (projectName) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
    return tslib_1.__generator(this, function (_a) {
        create_1.default(projectName, program);
        return [2 /*return*/];
    });
}); });
program
    .command('build')
    .description("\u6784\u5EFA\u9879\u76EE\u3002\u5C06TypeScript\u7F16\u8BD1\u6210js\u3002\n\n    \u4F8B\u5B50\uFF1A\n\n    $ build\n    $ build --format cjs,es,umd\n    $ build --entry src/example.ts\n    $ build --target node\n  ")
    .option('-f, --format <format>', '指定模块格式，默认为cjs,es', utils_1.commaSeparatedList, ['cjs', 'es'])
    .option('--entry, -i <entry>', '指定入口文件，默认为src/index.ts或者src/index.tsx')
    .option('--target <target>', '指定目标环境，可选项为web、node，默认为web', 'web')
    .option('--name <name>', '指定在UMD中的名称，默认会取package.json中的name')
    .option('--outDir <outDir>', "\u6307\u5B9A\u8F93\u51FA\u76EE\u5F55\uFF0C\u9ED8\u8BA4\u4E3A" + constants_1.DIST_PATH_NAME, constants_1.DIST_PATH_NAME)
    .action(function (options) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
    return tslib_1.__generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, build_1.runBuild(getBuildOptions_1.getBuildOptions(options))];
            case 1:
                _a.sent();
                return [2 /*return*/];
        }
    });
}); });
program
    .command('watch')
    .description("\u4EE5\u76D1\u542C\u6A21\u5F0F\u542F\u52A8\u9879\u76EE\u3002\u6BCF\u5F53\u4EE3\u7801\u53D1\u751F\u53D8\u5316\u5C31\u4F1A\u91CD\u65B0\u7F16\u8BD1\u3002\n\n  \u4F8B\u5B50\uFF1A\n\n    $ watch\n    $ watch --format cjs,es,umd\n    $ watch --entry src/example.ts\n    $ watch --target node\n  ")
    .option('-f, --format <format>', '指定模块格式，默认为cjs,es', utils_1.commaSeparatedList, ['cjs', 'es'])
    .option('--entry, -i <entry>', '指定入口文件，默认为src/index.ts或者src/index.tsx')
    .option('--target <target>', '指定目标环境，可选项为web、node，默认为web', 'web')
    .option('--name <name>', '指定在UMD中的名称，默认会取package.json中的name')
    .option('--outDir <outDir>', "\u6307\u5B9A\u8F93\u51FA\u76EE\u5F55\uFF0C\u9ED8\u8BA4\u4E3A" + constants_1.DIST_PATH_NAME, constants_1.DIST_PATH_NAME)
    .action(function (options) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
    return tslib_1.__generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, watch_1.runWatch(getBuildOptions_1.getBuildOptions(options))];
            case 1:
                _a.sent();
                return [2 /*return*/];
        }
    });
}); });
program.command('lint').description('代码检查');
program.command('test').description('单元测试');
program.command('format').description('格式化代码');
program.on('command:*', function () {
    var commandName = program.args[0];
    console.error(chalk_1.default.red('错误！') + " ts-lib-scripts\u6CA1\u6709" + chalk_1.default.red(commandName) + "\u547D\u4EE4\u3002\u60A8\u5982\u679C\u60F3\u521B\u5EFA\u9879\u76EE\uFF0C\u8BF7\u4F7F\u7528\u4E0B\u9762\u7684\u547D\u4EE4\u884C\uFF1A" + '\n\n  ' + chalk_1.default.green("npx ts-lib-scripts create " + commandName));
    process.exit(1);
});
var command = process.argv[2];
var directCmds = {
    test: test_1.test,
    lint: lint_1.lint,
    format: format_1.format,
};
if (Object.keys(directCmds).indexOf(command) !== -1) {
    var fn = directCmds[command];
    fn();
}
else {
    program.parse(process.argv);
}
//# sourceMappingURL=index.js.map