"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = require("path");
var ts_lib_scripts_utils_1 = require("ts-lib-scripts-utils");
var paths_1 = require("./config/paths");
/**
 * 获取打包js文件的路径
 *
 * @export
 * @param {string} outDir 输出目录
 * @param {('es' | 'cjs' | 'umd')} format 打包js的格式
 * @param {('development' | 'production')} env 运行环境
 * @returns
 */
function getOutputFilePath(outDir, format, env) {
    return path_1.resolve(outDir, ts_lib_scripts_utils_1.safePackageName(paths_1.getAppPackageInfo().name) + "." + format + "." + env + ".js");
}
exports.getOutputFilePath = getOutputFilePath;
/**
 * 获取库名称
 *
 * @export
 * @returns 返回库名称
 */
function getLibraryName() {
    return ts_lib_scripts_utils_1.safeVariableName(paths_1.getAppPackageInfo().name);
}
exports.getLibraryName = getLibraryName;
/**
 * 判断指定模块id是否为外部依赖
 *
 * @param {string} id 指定模块id
 * @returns {boolean} 如果指定模块id为外部依赖，则返回true；否则返回false。
 */
function external(id) {
    return !id.startsWith('.') && !path_1.isAbsolute(id);
}
exports.external = external;
/**
 * 将字符串解析为列表
 *
 * 如： `"item1,item2"`解析为`["item1", "item2"]`
 *
 * @param value 字符串值
 */
function commaSeparatedList(value) {
    return value ? value.split(',') : [];
}
exports.commaSeparatedList = commaSeparatedList;
// Taken from Create React App, react-dev-utils/clearConsole
// @see https://github.com/facebook/create-react-app/blob/master/packages/react-dev-utils/clearConsole.js
/**
 * 清除控制台
 */
function clearConsole() {
    process.stdout.write(process.platform === 'win32' ? '\x1B[2J\x1B[0f' : '\x1B[2J\x1B[3J\x1B[H');
}
exports.clearConsole = clearConsole;
//# sourceMappingURL=utils.js.map