"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/* eslint-disable no-console */
/* eslint-disable import/prefer-default-export */
var rollup_1 = require("rollup");
var lodash_1 = require("lodash");
var ora_1 = tslib_1.__importDefault(require("ora"));
var chalk_1 = tslib_1.__importDefault(require("chalk"));
var build_1 = require("./build");
var create_rollup_options_1 = require("./config/create-rollup-options");
var utils_1 = require("./utils");
var logError_1 = tslib_1.__importDefault(require("./logError"));
/**
 * 运行监听命令
 *
 * @param buildOptions 构建参数
 */
function runWatch(buildOptions) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var formats, envs, configs, spinner;
        var _this = this;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    formats = buildOptions.format;
                    envs = ['production', 'development'];
                    configs = lodash_1.flatMap(formats, function (formatMode) {
                        return envs.map(function (env) { return create_rollup_options_1.createRollupOptions(formatMode, env, buildOptions, true); });
                    }).map(function (_a) {
                        var input = _a[0], output = _a[1];
                        return (tslib_1.__assign({}, input, { output: output, watch: {
                                silent: true,
                                include: ['src/**'],
                                exclude: ['node_modules/**'],
                            } }));
                    });
                    spinner = ora_1.default().start();
                    return [4 /*yield*/, rollup_1.watch(configs).on('event', function (event) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                            return tslib_1.__generator(this, function (_a) {
                                switch (event.code) {
                                    case 'START':
                                        utils_1.clearConsole();
                                        spinner.start(chalk_1.default.bold.cyan('开始编译模块...'));
                                        break;
                                    case 'ERROR':
                                    case 'FATAL':
                                        spinner.fail(chalk_1.default.bold.red('编译失败'));
                                        logError_1.default(event.error);
                                        break;
                                    case 'END':
                                        spinner.succeed(chalk_1.default.bold.green('编译成功'));
                                        console.log(chalk_1.default.dim('开始监听变化'));
                                        break;
                                    default:
                                }
                                return [2 /*return*/];
                            });
                        }); })];
                case 1:
                    _a.sent();
                    build_1.createCjsIndexFile(buildOptions.outDir);
                    return [2 /*return*/];
            }
        });
    });
}
exports.runWatch = runWatch;
//# sourceMappingURL=watch.js.map